@@ -25,7 +25,6 @@ import org.jcodings.Config;
 import org.jcodings.IntHolder;
 import org.jcodings.ascii.AsciiTables;
 import org.jcodings.constants.CharacterType;
-import org.jcodings.exception.EncodingException;
 import org.jcodings.exception.ErrorCodes;
 import org.jcodings.exception.ErrorMessages;
 import org.jcodings.exception.InternalException;
@@ -50,7 +49,7 @@ abstract class BaseSJISEncoding extends CanBeTrailTableEncoding {
     @Override
     public int codeToMbcLength(int code) {
         if (code < 256) {
-            return SjisEncLen[code] == 1 ? 1 : 0;
+            return SjisEncLen[code] == 1 ? 1 : ErrorCodes.ERR_INVALID_CODE_POINT_VALUE;
         } else if (code <= 0xffff) {
             int low = code & 0xff;
             if (!SJIS_ISMB_TRAIL(low)) {
